<?php
/*

Plugin Name: PixoPoint List Nested Pages Plugin
Plugin URI: http://pixopoint.com/products/list-nested-pages/
Description: A WordPress plugin which adds a function to your site to display a list of pages, but ONLY include the pages you request along with their corresponding nested pages
Author: PixoPoint Web Development / Ryan Hellyer
Version: 0.1
Author URI: http://pixopoint.com/

Copyright (c) 2009 PixoPoint Web Development

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.



To use this plugin, simply declare the pixopoint_list_nestedpages() with
a comma delimited list of ID's you want to include wherever in your theme
that you want to display the list.


Example: To include the pages with ID's of 61, 171, 73, 75 and 77, you would add
the following to your theme where you require the lists (check for the function
first in case so that an error won't be triggered if you uninstall the plugin.

<?php
	if ( function_exists( 'pixopoint_list_nestedpages' )
		pixopoint_list_nestedpages( '61 ,171 ,73 ,75 ,77 ' ); ?>
?>


*/


/**
 * Creates a list of pages in which included top level pages incorporate
 * all nested pages regardless of whether those individual pages are
 * included or not
 */
function pixopoint_list_nestedpages( $include ) {
	$include = explode( ',', $include ); // Splits list of included ID's up
	// Generating the list itself
	foreach ( $include as $page_id ) {
		$page_id = intval( $page_id ); // Converting from string to integer
		$page = wp_list_pages( "echo=0&title_li=&include=$page_id" ); // Grabbing the designated top level menu item
		$submenu = wp_list_pages( "echo=0&title_li=&child_of=$page_id&depth=1" ); // Grabbing the sub-menu
		if ( $submenu )
			$page = str_replace( '</li>', "<ul>$submenu</ul></li>", $page ); // Nesting the sub-menu inside the top level menu item
		echo $page; // Displaying the HTML on the page
	}
}


